#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-hamlet
version: 0.4.0.11
id: xml-hamlet-0.4.0.11-d4dd0a3a044e0a8b26e9a07aceb3d758
key: xmlha_I4DQDUt2uZZ9s0CYgfZavD
license: BSD3
maintainer: michael@snoyman.com
homepage: http://www.yesodweb.com/
synopsis: Hamlet-style quasiquoter for XML content
description:
    Hamlet-style quasiquoter for XML content
category: Text
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.Hamlet.XML
hidden-modules: Text.Hamlet.XMLParse
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-hamlet-0.4.0.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-hamlet-0.4.0.11
hs-libraries: HSxml-hamlet-0.4.0.11-I4DQDUt2uZZ9s0CYgfZavD
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    shakespeare-2.0.7-eabbf817e7dec503c762bf3ca866120e
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    xml-conduit-1.3.3.1-daddc82b56f1f7b1ac0bd9d16f4322ab
haddock-interfaces: /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html: /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
